"use strict";

var _interopRequireDefault = require("@babel/runtime-corejs3/helpers/interopRequireDefault");

var _Object$defineProperty = require("@babel/runtime-corejs3/core-js-stable/object/define-property");

_Object$defineProperty(exports, "__esModule", {
  value: true
});

exports.BlockchainProcessLauncher = void 0;

var _bind = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/instance/bind"));

var _embarkI18n = require("embark-i18n");

var _embarkCore = require("embark-core");

var _embarkUtils = require("embark-utils");

const constants = require('embark-core/constants');

class BlockchainProcessLauncher {
  constructor(options) {
    this.events = options.events;
    this.env = options.env;
    this.logger = options.logger;
    this.normalizeInput = options.normalizeInput;
    this.blockchainConfig = options.blockchainConfig;
    this.locale = options.locale;
    this.isDev = options.isDev;
    this.client = options.client;
    this.embark = options.embark;
  }

  processEnded(code) {
    this.logger.error((0, _embarkI18n.__)('Blockchain process ended before the end of this process. Try running blockchain in a separate process using `$ embark blockchain`. Code: %s', code));
  }

  startBlockchainNode(readyCb) {
    var _context;

    this.logger.info((0, _embarkI18n.__)('Starting Blockchain node in another process').cyan);
    this.blockchainProcess = new _embarkCore.ProcessLauncher({
      name: 'blockchain',
      modulePath: (0, _embarkUtils.joinPath)(__dirname, './blockchainProcess.js'),
      logger: this.logger,
      events: this.events,
      silent: this.logger.logLevel !== 'trace',
      exitCallback: (0, _bind.default)(_context = this.processEnded).call(_context, this),
      embark: this.embark
    });
    this.blockchainProcess.send({
      action: constants.blockchain.init,
      options: {
        blockchainConfig: this.blockchainConfig,
        client: this.client,
        env: this.env,
        isDev: this.isDev,
        locale: this.locale,
        certOptions: this.embark.config.webServerConfig.certOptions,
        events: this.events
      }
    });
    this.blockchainProcess.once('result', constants.blockchain.blockchainReady, () => {
      this.logger.info((0, _embarkI18n.__)('Blockchain node is ready').cyan);
      readyCb();
    });
    this.blockchainProcess.once('result', constants.blockchain.blockchainExit, () => {
      // tell everyone that our blockchain process (ie geth) died
      this.events.emit(constants.blockchain.blockchainExit); // then kill off the blockchain process

      this.blockchainProcess.kill();
    });
    this.events.setCommandHandler('logs:ethereum:enable', () => {
      this.blockchainProcess.setSilent(false);
    });
    this.events.setCommandHandler('logs:ethereum:disable', () => {
      this.blockchainProcess.setSilent(true);
    });
    this.events.on('exit', () => {
      this.blockchainProcess.send('exit');
    });
  }

  stopBlockchainNode(cb) {
    if (this.blockchainProcess) {
      this.events.once(constants.blockchain.blockchainExit, cb);

      this.blockchainProcess.exitCallback = () => {}; // don't show error message as the process was killed on purpose


      this.blockchainProcess.send('exit');
    }
  }

}

exports.BlockchainProcessLauncher = BlockchainProcessLauncher;
//# sourceMappingURL=blockchainProcessLauncher.js.map